@@ -13,6 +13,7 @@ function(df, nf=2, rec=FALSE,niter=100, tol = 1e-9){
     tol<-1e-9 # tol pour la convergence
     nc <- ncol(df)
     nr <- nrow(df)
+    nr.na <- apply(df, 2, function(x) sum(!is.na(x)))
     if (rec)
         x<-list(li=matrix(0,nr,nf),c1=matrix(0,nc,nf),co=matrix(0,nc,nf),
         eig=rep(0,nf),nb=rep(0,nf),rec=matrix(0,nr,nc))
@@ -25,7 +26,7 @@ function(df, nf=2, rec=FALSE,niter=100, tol = 1e-9){
 
     #X<-scale(df, center=T, scale=T, na.rm=TRUE)
     cmeans <- colMeans(df, na.rm=TRUE)
-    csd <- apply(df, 2, sd, na.rm=TRUE) * (nr - 1) / nr
+    csd <- apply(df, 2, sd, na.rm=TRUE) * (nr.na - 1) / nr.na
     X <- sweep(sweep(df, 2, cmeans, "-"), 2, csd, "/")
     x$tab<-X
     for (h in 1:nf) {
@@ -93,8 +94,8 @@ print.nipals<-function (x, ...)
         "mode", "content")))
     sumry[1, ] <- c("$nb", length(x$nb), mode(x$nb), "number of iterations")
     sumry[2, ] <- c("$eig", length(x$eig), mode(x$eig), "eigen values")
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("\n")
     sumry <- array("", c(4, 4), list(1:4, c("data.frame", "nrow",
         "ncol", "content")))
@@ -102,8 +103,8 @@ print.nipals<-function (x, ...)
     sumry[2, ] <- c("$li", nrow(x$li), ncol(x$li), "row coordinates")
     sumry[3, ] <- c("$co", nrow(x$co), ncol(x$co), "column coordinates")
     sumry[4, ] <- c("$c1", nrow(x$c1), ncol(x$c1), "column normed scores")
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("other elements: ")
     if (length(names(x))==8)
         cat("NULL\n")
